#include <Arduino.h>

// Arduino Multifunkční shield

// nastavení propojovacích pinů pro segmentový displej
#define pinLatch 4
#define pinClk 7
#define pinData 8
// nastavení propojovacích pinů pro trimr
#define trimr A0
// nastavení propojovacích pinů pro LED diody
const byte LED[] = {13,12,11,10};
// nastavení propojovacích pinů pro tlačítka
#define tlacitkoA1 A1
#define tlacitkoA2 A2
#define tlacitkoA3 A3
// nastavení propojovacích pinů pro sirénku
#define pinSirenka 3
// definování stavů pro vypnutí a zapnutí
#define ON  LOW
#define OFF HIGH

// proměnná pro počítadlo stisku tlačítek
int pocitadlo = 0;
// mapa čísel pro segmentový displej - čísla 0 až 9
const byte mapaSegment[] = {0xC0,0xF9,0xA4,0xB0,0x99,0x92,0x82,0xF8,0X80,0X90};
// mapa číslic na segmentovém displeji
const byte mapaCisloSeg[] = {0xF1,0xF2,0xF4,0xF8};
 


void setup () {
  // nastavení propojovacích pinů pro
  // segmentový displej, LED diody
  // a sirénku jako výstup
  pinMode(pinLatch, OUTPUT);
  pinMode(pinClk, OUTPUT);
  pinMode(pinData, OUTPUT);
  pinMode(LED[0], OUTPUT);
  pinMode(LED[1], OUTPUT);
  pinMode(LED[2], OUTPUT);
  pinMode(LED[3], OUTPUT);
  pinMode(pinSirenka, OUTPUT);
  // vypnutí všech LED diod
  digitalWrite(LED[0], OFF);
  digitalWrite(LED[1], OFF);
  digitalWrite(LED[2], OFF);
  digitalWrite(LED[3], OFF);

  /* dvě možnosti pro vypnutí sirénka*/
  digitalWrite(pinSirenka, HIGH); //vypnutí sirénky (obrácená logika)
  
  noTone(pinSirenka);   //vypnutí sirénky pomocí PWM

}
void loop() {
  /* práce se segmentovým displejem a trimrem */
  // vytvoření proměnné pro načtení analogového vstupu z trimru
  int analogTrimr = analogRead(trimr);
  // zapsání analogové hodnoty na segmentový displej,
  // zápis je po číslech - tisícovky, stovky, ..
  zapisCisloNaSegment(0 , analogTrimr / 1000);
  zapisCisloNaSegment(1 , (analogTrimr / 100) % 10);
  zapisCisloNaSegment(2 , (analogTrimr / 10) % 10);
  zapisCisloNaSegment(3 , analogTrimr % 10);
  /* obsluha tlačítek, LED diod a sirénky */
  // načtení stavu tlačítek do proměnných
  bool tlac1 = digitalRead(tlacitkoA1);
  bool tlac2 = digitalRead(tlacitkoA2);
  bool tlac3 = digitalRead(tlacitkoA3);
  // pokud je stisknuto první tlačítko, přičteme jedničku
  // do počítadla a zobrazíme na LED diodách v binárním tvaru
  if (tlac1 == ON) {
    pocitadlo++;
    
    // na 4 LED diody lze vypsat maximálně číslo 15 v bin. tvaru
    if (pocitadlo > 15) {
      pocitadlo = 15;
      
    }
    // zápis pomocí funkce bitRead(proměnná, pozice bitu)
    // nutné znegovat pomocí ! - opačná logika zapínání LED diod
    digitalWrite(LED[0], !(bitRead(pocitadlo, 0)));
    digitalWrite(LED[1], !(bitRead(pocitadlo, 1)));
    digitalWrite(LED[2], !(bitRead(pocitadlo, 2)));
    digitalWrite(LED[3], !(bitRead(pocitadlo, 3)));
    digitalWrite(pinSirenka, HIGH); //vypnutí sirénky
    // pauza pro plynulejší přičítaní mezi stisky tlačítek
    delay(200);
  }
  // pokud je stisknuto druhé tlačítko, odečteme jedničku
  // z počítadla, zbytek je stejný jako u tlačítka 1
  if (tlac2 == ON) {
    pocitadlo--;
    if (pocitadlo < 0) {
      pocitadlo = 0;
    }
    digitalWrite(LED[0], !(bitRead(pocitadlo, 0)));
    digitalWrite(LED[1], !(bitRead(pocitadlo, 1)));
    digitalWrite(LED[2], !(bitRead(pocitadlo, 2)));
    digitalWrite(LED[3], !(bitRead(pocitadlo, 3)));
    digitalWrite(pinSirenka, LOW); //zapnutí sirénky
    delay(200);
  }
  // pokud je stisknuto třetí tlačítko, zahrajeme tón
  if (tlac3 == ON) {

       int ton = 440 + (analogTrimr); //tón se mění podle hodnotu trimru
   
    tone(pinSirenka, ton, 20); //zapnutí sirénky o určitém tónu (pomocí PWM)
  }
}
// podprogram pro zápis čísla na zadaný segment
 void zapisCisloNaSegment(byte segment, byte hodnota) {
  digitalWrite(pinLatch,LOW);
  shiftOut(pinData, pinClk, MSBFIRST, mapaSegment[hodnota]);
  shiftOut(pinData, pinClk, MSBFIRST, mapaCisloSeg[segment] );
  digitalWrite(pinLatch,HIGH);
}
